//////////////////////////////////////////////////////////////////////////////
//	Module		: ClsStd.h													//
//	Function	: Base class for STDbus Smart A/D boards.					//
//	Author		: Jim Lamberson												//
//////////////////////////////////////////////////////////////////////////////

#ifndef Def_ClsStd
#define Def_ClsStd

#include "ClsSmad.h"

class ClsStd : public ClsSmad {
public:
	ClsStd( short ProductID, long Adrs, short NumCh );
	void			CoefficientsSet		( short ch, double a, double b, double c );
	void			GageSpanSet			( short ch, short val );
	void			GageTareSet			( short ch );
	void			GageZeroSet			( short ch );
	short			ProductIDGet		();
	void			SensorTypeSet		( short Chan, short LogSDC );
protected:
	// Command functions.
	void			CmdClose			();
	void			CmdResetBoard		();
	unsigned char	CmdStatusFlagsGet	();
	// Helper functions.
	bool			ActiveALARM			();
	void			DeclareResponse		( short nBytes );
	void			HandshakeDatString	( short nBytes );
	bool			HandshakeWait		( const char mask, const char xormask, const double maxtime );
	char			InByteDirect		( long Adrs );
	void			OutByteDirect		( long Adrs, char Value );
	void			SendByte			( char val );
	// Hardware access functions that are provided by a derived class.
	virtual char	InByte				( long Adrs )				= 0;
	virtual void	OutByte				( long Adrs, char Value )	= 0;
private:
	double			GageZero;		// Used to cal gages on STDbus types in a fashion similar to ISA types.
};

#endif
