///////////////////////////////////////////////////////////////////////////
// Module	: SmartADDefs.h
// Function	: Definitions header for Smart A/D device interface classes.
// Author	: Jim Lamberson
///////////////////////////////////////////////////////////////////////////

#ifndef DEF_SmartADDefs
#define DEF_SmartADDefs

// Bit flags in StatusFlags ------------------------------------------------

#define STAT_REJECT50HZ		0x0800			// Operating in 50 Hz rejection mode.
#define STAT_SLEEPING		0x0400			// Operating in low-power standby mode.
#define STAT_HISPEED		0x0200			// Operating in high-speed, low-resolution mode.
		//					0x0100			//   spare.
#define STAT_CRMT			0x0080			// Command register empty.
#define STAT_DAV			0x0040			// Data available.
#define STAT_ALARM			0x0020			// Alarm(s) sounding.
#define STAT_FAULT			0x0010			// Board Fault LED is active.

// Bit flags used to log errors to MyFaultFlags and external err handler ---

#define FAULT_DAV			0x00000001		// DAV fault detected.
#define	FAULT_CRMT			0x00000002		// CRMT fault detected.
#define	FAULT_LED			0x00000004		// Fault LED is stuck on.
#define FAULT_OPEN			0x00000008		// Can't open I/O Driver (i.e., WinSock, WinDrvr).
#define FAULT_REG			0x00000010		// Can't register card with I/O Driver.
#define FAULT_CREATE		0x00000040		// Can't create board object instance.
#define FAULT_SEND			0x00000080		// Can't send packet to Ethernet Smart A/D.
#define FAULT_RECEIVE		0x00000080		// Ethernet Smart A/D not responding.

// Bit flags used by external error handler only ---------------------------

#define ERR_BADPARM			0x00010000		// Invalid property value (chan number too high, etc.).
#define ERR_BADCMD			0x00020000		// Command not supported on this product.

// TYPE DEFINITIONS ******************************************************************

typedef void (* FPTR)(long);	// Pointer to application interrupt or error callback function.

// MACROS ****************************************************************************

#ifndef LOBYTE
#define LOBYTE(w)           ((unsigned char)(w))
#endif

#ifndef HIBYTE
#define HIBYTE(w)           ((unsigned char)((unsigned short)(w) >> 8))
#endif

#endif // DEF_SmartADDefs
